==> amatak-shop-1.0.4.tar.gz: amatak-shop-1.0.4/README.md <==
__Amatak Online Shop__ was created and is currently maintained and developed by Amatak the full documentation can be found in
[amatak.org](https://amatak.org/docs/projects/AmatakOnlineShop)

### Join our  [Stack Overflow](https://stackoverflow.com/users/22269946/amatak)

To clone this project from 
[GitHub](https://github.com/amatak-org/AmatakOnlineShop).


# Https
````Https
https://github.com/amatak-org/AmatakOnlineShop.git
````
# SSH
````SSH
git@github.com:amatak-org/AmatakOnlineShop.git
````
# GITHUB CLI
````GITHUB CLI
gh repo clone amatak-org/AmatakOnlineShop
````

### Here is briefly descript about this online shopping.



__Amatak Online Shop is a small online store shopping that everyone can be owned.__
__To get started head up to [DjangoProject](https://www.djangoproject.com/) page and follow all the way of tutorial there__
__This is the best way to get started twith this project if you are not familiar with the models.__

### Install from py library:

````
pip install amatak-shop
````

### add amatak to django app installed:
# in Django App setting.

````
pip install Django
````


### Current Contents.
# Current Version 1.0.4
# features:
## Categories:

- Women Fashion
- Men Fashion
- Phones & Telecommunications
- Computer,Office & Security
- Consumer & Electronics
- Jewelry & Watches
- Home,pet & Appliances
- Bags & Shoes
- Toys, Kids & Babies
- Outdoor Fun & Sports
- Beauty, Health & Hair
- Automobiles & Motorcycles
- Tools & Home Improvement

## Store' Models:
- Address
- Category
- Item
- Order
- Order Item
- Payment
- Refund
- User Profile
- User Receiver Profile
- Vender Store
- Seller Dasboard
- Customer Reviews
- Shipping Integrate
## Payment' Gateway:
- Stripe
- Paypal

## Frontend:
- [GetWeb](https://getweb.dev/)
- [Bootrap](https://getbootstrap.com/)
- [Bulma](https://bulma.io/)
- [Mdbootrap](https://mdbootstrap.com/)
- [VuesJs](https://vuejs.org/)


## Backend:
- [Django](https://www.djangoproject.com/)


# Homepage Screen
![Home Screen](https://pub-3f83785b7aa64195b0afb81d8ef9ca5c.r2.dev/Images/cdn.amatak.org/screenshot.png)

# Client Checkout With Coupon
![Check Out cart](https://pub-3f83785b7aa64195b0afb81d8ef9ca5c.r2.dev/Images/cdn.amatak.org/screenshot_checkout_with_coupon.png)

# Client Checkout Views
![Check Out cart](https://pub-3f83785b7aa64195b0afb81d8ef9ca5c.r2.dev/Images/cdn.amatak.org/screenshot_checkout.png)

==> amatak-shop-1.0.5.tar.gz: amatak-shop-1.0.5/README.md <==
__Amatak Online Shop__ was created and is currently maintained and developed by Amatak the full documentation can be found in
[amatak.org](https://amatak.org/docs/projects/AmatakOnlineShop)

### Join our  [Stack Overflow](https://stackoverflow.com/users/22269946/amatak)

To clone this project from 
[GitHub](https://github.com/amatak-org/AmatakOnlineShop).


# Https
````Https
https://github.com/amatak-org/AmatakOnlineShop.git
````
# SSH
````SSH
git@github.com:amatak-org/AmatakOnlineShop.git
````
# GITHUB CLI
````GITHUB CLI
gh repo clone amatak-org/AmatakOnlineShop
````

### Here is briefly descript about this online shopping.



__Amatak Online Shop is a small online store shopping that everyone can be owned.__
__To get started head up to [DjangoProject](https://www.djangoproject.com/) page and follow all the way of tutorial there__
__This is the best way to get started twith this project if you are not familiar with the models.__

### Install from py library:

````
pip install amatak-shop
````

### Installed App:
# add (amatak_shop) in Django App setting.

````
INSTALLED_APPS = [
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'amatak_shop',
]
````


### Current Contents.
# Current Version 1.0.4
# features:
## Categories:

- Women Fashion
- Men Fashion
- Phones & Telecommunications
- Computer,Office & Security
- Consumer & Electronics
- Jewelry & Watches
- Home,pet & Appliances
- Bags & Shoes
- Toys, Kids & Babies
- Outdoor Fun & Sports
- Beauty, Health & Hair
- Automobiles & Motorcycles
- Tools & Home Improvement

## Store' Models:
- Address
- Category
- Item
- Order
- Order Item
- Payment
- Refund
- User Profile
- User Receiver Profile
- Vender Store
- Seller Dasboard
- Customer Reviews
- Shipping Integrate
## Payment' Gateway:
- Stripe
- Paypal

## Frontend:
- [GetWeb](https://getweb.dev/)
- [Bootrap](https://getbootstrap.com/)
- [Bulma](https://bulma.io/)
- [Mdbootrap](https://mdbootstrap.com/)
- [VuesJs](https://vuejs.org/)


## Backend:
- [Django](https://www.djangoproject.com/)


# Homepage Screen
![Home Screen](https://pub-3f83785b7aa64195b0afb81d8ef9ca5c.r2.dev/Images/cdn.amatak.org/screenshot.png)

# Client Checkout With Coupon
![Check Out cart](https://pub-3f83785b7aa64195b0afb81d8ef9ca5c.r2.dev/Images/cdn.amatak.org/screenshot_checkout_with_coupon.png)

# Client Checkout Views
![Check Out cart](https://pub-3f83785b7aa64195b0afb81d8ef9ca5c.r2.dev/Images/cdn.amatak.org/screenshot_checkout.png)
